@@ -2,7 +2,7 @@ package Alien::Build;
 
 use strict;
 use warnings;
-use 5.008001;
+use 5.008004;
 use Path::Tiny ();
 use Carp ();
 use File::chdir;
@@ -13,7 +13,7 @@ use Config ();
 use Alien::Build::Log;
 
 # ABSTRACT: Build external dependencies for use in CPAN
-our $VERSION = '1.98'; # VERSION
+our $VERSION = '2.28'; # VERSION
 
 
 sub _path { goto \&Path::Tiny::path }
@@ -1165,7 +1165,7 @@ Alien::Build - Build external dependencies for use in CPAN
 
 =head1 VERSION
 
-version 1.98
+version 2.28
 
 =head1 SYNOPSIS
 
@@ -2005,7 +2005,7 @@ be used by some Fetch plugins, if they support it.
 =head1 SUPPORT
 
 The intent of the C<Alien-Build> team is to support as best as possible
-all Perls from 5.8.1 to the latest production version.  So long as they
+all Perls from 5.8.4 to the latest production version.  So long as they
 are also supported by the Perl toolchain.
 
 Please feel encouraged to report issues that you encounter to the
@@ -2054,7 +2054,7 @@ not have been possible without him getting the project started.  Thanks to his s
 I have been able to augment the original L<Alien::Base> system with a reliable set
 of tools (L<Alien::Build>, L<alienfile>, L<Test::Alien>), which make up this toolset.
 
-The original L<Alien::Base> is still copyright (c) 2012-2017 Joel Berger.  It has
+The original L<Alien::Base> is still copyright (c) 2012-2020 Joel Berger.  It has
 the same license as the rest of the Alien::Build and related tools distributed as
 C<Alien-Build>.  Joel Berger thanked a number of people who helped in in the development
 of L<Alien::Base>, in the documentation for that module.
@@ -2066,6 +2066,9 @@ in the early development of L<Alien::Build> were the early adopters Chase Whiten
 WBRASWELL, author of L<Alien::JPCRE2> and L<Alien::PCRE2>) and Ahmad Fatoum (a3f,
 ATHREEF, author of L<Alien::libudev> and L<Alien::LibUSB>).
 
+The Alien ecosystem owes a debt to Dan Book, who goes by Grinnz on IRC, for answering
+question about how to use L<Alien::Build> and friends.
+
 =head1 AUTHOR
 
 Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
@@ -2124,6 +2127,8 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
