@@ -2,13 +2,13 @@ package Alien::Build::Plugin::Download::Negotiate;
 
 use strict;
 use warnings;
+use 5.008004;
 use Alien::Build::Plugin;
-use Module::Load ();
 use Alien::Build::Util qw( _has_ssl );
 use Carp ();
 
 # ABSTRACT: Download negotiation plugin
-our $VERSION = '1.94'; # VERSION
+our $VERSION = '2.28'; # VERSION
 
 
 has '+url' => undef;
@@ -48,6 +48,20 @@ sub pick
   ($fetch, @decoders);
 }
 
+sub _pick_decoder
+{
+  my($self) = @_;
+
+  if(eval { require Mojo::DOM58; Mojo::DOM58->VERSION(1.00); 1 })
+  { return "Decode::Mojo" }
+  elsif(eval { require Mojo::DOM; require Mojolicious; Mojolicious->VERSION('7.00'); 1 })
+  { return "Decode::Mojo" }
+  elsif(eval { require HTML::LinkExtor; 1; })
+  { return "Decode::HTML" }
+  else
+  { return "Decode::Mojo" }
+}
+
 sub _pick
 {
   my($self) = @_;
@@ -62,32 +76,32 @@ sub _pick
   {
     if($self->bootstrap_ssl && ! _has_ssl)
     {
-      return (['Fetch::CurlCommand','Fetch::Wget'], 'Decode::Mojo');
+      return (['Fetch::CurlCommand','Fetch::Wget'], __PACKAGE__->_pick_decoder);
     }
     elsif(_has_ssl)
     {
-      return ('Fetch::HTTPTiny', 'Decode::Mojo');
+      return ('Fetch::HTTPTiny', __PACKAGE__->_pick_decoder);
     }
     elsif(do { require Alien::Build::Plugin::Fetch::CurlCommand; Alien::Build::Plugin::Fetch::CurlCommand->protocol_ok('https') })
     {
-      return ('Fetch::CurlCommand', 'Decode::Mojo');
+      return ('Fetch::CurlCommand', __PACKAGE__->_pick_decoder);
     }
     else
     {
-      return ('Fetch::HTTPTiny', 'Decode::Mojo');
+      return ('Fetch::HTTPTiny', __PACKAGE__->_pick_decoder);
     }
   }
   elsif($self->scheme eq 'http')
   {
-    return ('Fetch::HTTPTiny', 'Decode::Mojo');
+    return ('Fetch::HTTPTiny', __PACKAGE__->_pick_decoder);
   }
   elsif($self->scheme eq 'ftp')
   {
     if($ENV{ftp_proxy} || $ENV{all_proxy})
     {
       return $self->scheme =~ /^ftps?/
-        ? ('Fetch::LWP', 'Decode::DirListing', 'Decode::Mojo')
-        : ('Fetch::LWP', 'Decode::Mojo');
+        ? ('Fetch::LWP', 'Decode::DirListing', __PACKAGE__->_pick_decoder)
+        : ('Fetch::LWP', __PACKAGE__->_pick_decoder);
     }
     else
     {
@@ -181,7 +195,7 @@ Alien::Build::Plugin::Download::Negotiate - Download negotiation plugin
 
 =head1 VERSION
 
-version 1.94
+version 2.28
 
 =head1 SYNOPSIS
 
@@ -349,9 +363,11 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2019 by Graham Ollis.
+This software is copyright (c) 2011-2020 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
