@@ -2,10 +2,11 @@ package Test::Alien::Run;
 
 use strict;
 use warnings;
+use 5.008004;
 use Test2::API qw( context );
 
 # ABSTRACT: Run object
-our $VERSION = '1.79'; # VERSION
+our $VERSION = '2.28'; # VERSION
 
 
 sub out    { shift->{out} }
@@ -37,10 +38,10 @@ sub success
 sub exit_is
 {
   my($self, $exit, $message) = @_;
-  
+
   $message ||= "command exited with value $exit";
   my $ok = $self->exit == $exit;
-  
+
   my $ctx = context();
   $ctx->ok($ok, $message);
   $ctx->diag("  actual exit value was: @{[ $self->exit ]}") unless $ok;
@@ -52,10 +53,10 @@ sub exit_is
 sub exit_isnt
 {
   my($self, $exit, $message) = @_;
-  
+
   $message ||= "command exited with value not $exit";
   my $ok = $self->exit != $exit;
-  
+
   my $ctx = context();
   $ctx->ok($ok, $message);
   $ctx->diag("  actual exit value was: @{[ $self->exit ]}") unless $ok;
@@ -67,11 +68,11 @@ sub exit_isnt
 sub _like
 {
   my($self, $regex, $source, $not, $message) = @_;
-  
+
   my $ok = $self->{$source} =~ $regex;
   $ok = !$ok if $not;
-  
-  my $ctx = context();  
+
+  my $ctx = context();
   $ctx->ok($ok, $message);
   unless($ok)
   {
@@ -81,7 +82,7 @@ sub _like
     $ctx->diag("    $regex");
   }
   $ctx->release;
-  
+
   $self;
 }
 
@@ -120,7 +121,7 @@ sub err_unlike
 sub note
 {
   my($self) = @_;
-  my $ctx = context();  
+  my $ctx = context();
   $ctx->note("[cmd]");
   $ctx->note("  @{$self->{cmd}}");
   if($self->out ne '')
@@ -172,7 +173,7 @@ Test::Alien::Run - Run object
 
 =head1 VERSION
 
-version 1.79
+version 2.28
 
 =head1 SYNOPSIS
 
@@ -348,9 +349,11 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2019 by Graham Ollis.
+This software is copyright (c) 2011-2020 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
